<?xml version="1.0"?>
<xsl:stylesheet version = "1.0" xmlns:xsl = "http://www.w3.org/1999/XSL/Transform" xmlns:docs="http://tempuri.org/docs" xmlns:ix="urn:RevisableObjectImportTemplate.xsd" exclude-result-prefixes="docs">
	<docs:transformationMetaData>
		<docs:name>Excel Transformation</docs:name>
		<docs:description>Excel file containing all attributes except TableAttributes. No incoming or outgoing traces. Must use 'Convert RTF to plain text'.</docs:description>
		<docs:extension>.xls</docs:extension>
    <docs:onlyAsPlaintext>true</docs:onlyAsPlaintext>
	</docs:transformationMetaData>
	<xsl:output method="xml" indent="yes"/>
	<xsl:template match="/">
		<Workbook xmlns="urn:schemas-microsoft-com:office:spreadsheet"
    xmlns:o="urn:schemas-microsoft-com:office:office"
    xmlns:x="urn:schemas-microsoft-com:office:excel"
    xmlns:ss="urn:schemas-microsoft-com:office:spreadsheet"
    xmlns:html="http://www.w3.org/TR/REC-html40">
			<Worksheet ss:Name="Sheet1">
				<Table>
					<xsl:apply-templates/>
				</Table>	
			</Worksheet>
		</Workbook>
	</xsl:template>

	<xsl:template name="Header" match="ix:DocumentObjects">
		<!--create a header-->
		<Row xmlns="urn:schemas-microsoft-com:office:spreadsheet" xmlns:ss="urn:schemas-microsoft-com:office:spreadsheet">
			<Cell>
				<Data ss:Type="String">Project Name</Data>
			</Cell>
			<Cell>
				<Data ss:Type="String">ID</Data>
			</Cell>
			<Cell>
				<Data ss:Type="String">Title</Data>
			</Cell>
			<Cell>
				<Data ss:Type="String">Disabled</Data>
			</Cell>
			<xsl:for-each select="ix:DocumentObject[1]/ix:Attributes[1]/ix:Attribute[@AttributeType != 'TableAttribute']">
				<Cell>
					<Data ss:Type="String">
				<xsl:value-of select="@AttributeName"/>
					</Data>
				</Cell>
			</xsl:for-each>
			
		</Row>

		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template name="DocumentObjectsToExcel" match="ix:DocumentObject">
		<Row xmlns="urn:schemas-microsoft-com:office:spreadsheet" xmlns:ss="urn:schemas-microsoft-com:office:spreadsheet">
			<Cell>
				<Data ss:Type="String">
					<xsl:value-of select="normalize-space(@ProjectName)"/>
				</Data>
			</Cell>
			<Cell>
				<Data ss:Type="String">
					<xsl:value-of select="normalize-space(@ID)"/>
				</Data>
			</Cell>
			<Cell>
				<Data ss:Type="String">
					<xsl:value-of select="normalize-space(@Title)"/>
				</Data>
			</Cell>
			<Cell>
				<Data ss:Type="String">
					<xsl:value-of select="normalize-space(@Disabled)"/>
				</Data>
			</Cell>

			<!--get all attributes except tables-->
			<xsl:for-each select="ix:Attributes/ix:Attribute[@AttributeType != 'TableAttribute']">
				<Cell>
					<Data ss:Type="String">
            <xsl:variable name="myString" select="."/>
            <xsl:variable name="firstReplaceString">
              <xsl:call-template name="replaceCharsInString">
                <xsl:with-param name="stringIn" select="string($myString)"/>
                <xsl:with-param name="charsIn" select="'¢¢'"/>
                <xsl:with-param name="charsOut" select="'\n'"/>
              </xsl:call-template>
            </xsl:variable>
            <xsl:variable name="secondReplaceString">
              <xsl:call-template name="replaceCharsInString">
                <xsl:with-param name="stringIn" select="string($firstReplaceString)"/>
                <xsl:with-param name="charsIn" select="'££'"/>
                <xsl:with-param name="charsOut" select="'\r'"/>
              </xsl:call-template>
            </xsl:variable>
            <xsl:variable name="theFinalString" select="string($secondReplaceString)"/>

            <xsl:copy-of select="$theFinalString"/>
					</Data>
				</Cell>
			</xsl:for-each>
		</Row>
	</xsl:template>
  <xsl:template name="replaceCharsInString">
    <xsl:param name="stringIn"/>
    <xsl:param name="charsIn"/>
    <xsl:param name="charsOut"/>
    <xsl:choose>
      <xsl:when test="contains($stringIn,$charsIn)">
        <xsl:value-of select="concat(substring-before($stringIn,$charsIn),$charsOut)"/>
        <xsl:call-template name="replaceCharsInString">
          <xsl:with-param name="stringIn" select="substring-after($stringIn,$charsIn)"/>
          <xsl:with-param name="charsIn" select="$charsIn"/>
          <xsl:with-param name="charsOut" select="$charsOut"/>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$stringIn"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
</xsl:stylesheet>